@@ -2,9 +2,9 @@
 
 # Build zipfiles for Pango on Win32: separate runtime and developer packages
 
-ZIP=/tmp/pango-1.8.1-`date +%Y%m%d`.zip
-DEVZIP=/tmp/pango-dev-1.8.1-`date +%Y%m%d`.zip
-cd /usr
+ZIP=/tmp/pango-1.9.1-`date +%Y%m%d`.zip
+DEVZIP=/tmp/pango-dev-1.9.1-`date +%Y%m%d`.zip
+cd /opt/rendering
 
 DLLDIR=lib
 [ -f bin/libpango-1.0-0.dll ] && DLLDIR=bin
